#include "fresh.h"

#include <Arduino.h> // configTime()
#include <time.h>

TimeCheck::TimeCheck(uint32_t allowedTimeOffset) {
    allowedOffset = allowedTimeOffset;
}

void TimeCheck::configureNTP(int32_t offsetToGMT, int32_t offsetDaylightSavings, const char* serverUrl) {
    configTime(offsetToGMT, offsetDaylightSavings, serverUrl);
}

void TimeCheck::printLocalTime() {
    struct tm timeinfo;
    if (getLocalTime(&timeinfo)) {
        Serial.println(&timeinfo, "[INFO] Time is %A, %d. %B %Y %H:%M:%S");
    } else {
        Serial.println("[WARN] No local time available");
    }
}

uint32_t TimeCheck::getEpochTime() {
    time_t now;
    struct tm timeinfo;
    if (!getLocalTime(&timeinfo)) {
        Serial.println("[WARN] Failed to obtain local time");
        return(0);
    }
    time(&now);
    return now;
}

bool TimeCheck::isMessageTimeAcceptable(uint32_t t) {
    uint32_t localTime = getEpochTime();
    if (localTime == 0) {
        Serial.println("No epoch time available");
        return false;
    }
    if (t > localTime + allowedOffset) {
        return false;
    }
    if (t < localTime - allowedOffset) {
        return false;
    }
    return true;
}